<?php
if (!defined('B_PROLOG_INCLUDED') || B_PROLOG_INCLUDED !== true) {
    exit();
}
if (!class_exists('DeloProcessor')) {
    require __DIR__ . '/DeloProcessor.php';
}
$orderId = (int)$_GET['o_order_id'];
if (empty($orderId)) {
    DeloProcessor::sendResponse(DeloProcessor::setResponse(2, 'Parameter o.order_id not valid'));
}
try {
    $arOrder = DeloProcessor::findOrder($orderId);
    if (empty($arOrder['ID'])) {
        DeloProcessor::sendResponse(DeloProcessor::setResponse(2, 'Order №' . $_GET['o_order_id'] . ' not found'));
    }
    $paymentSettings = DeloProcessor::getPaymentSettings($arOrder['PAY_SYSTEM_ID'], $arOrder['PERSON_TYPE_ID']);
    $errors = [];
    if (empty($paymentSettings['SHOP_PCID'])) {
        $errors[] = 'Empty shop_pcid';
    }
    if ($paymentSettings['SHOP_PCID'] != $_GET['merch_id']) {
        $errors[] = 'Illegal parameter merch_id';
    }
    if (empty($paymentSettings['ACCOUNT_PCID'])) {
        $errors[] = 'Empty account_pcid';
    }
    if (empty($paymentSettings['AFTER_STATUS'])) {
        $errors[] = 'Empty after_status';
    }
    if ($paymentSettings['CURRENCY'] != '643') {
        $errors[] = 'Incorrect currency';
    }
    if (empty($paymentSettings['DECLINE_URL'])) {
        $errors[] = 'Empty decline_url';
    }
    if (empty($paymentSettings['SUCCESS_URL'])) {
        $errors[] = 'Empty success_url';
    }
    if (!DeloProcessor::checkCertificate($paymentSettings)) {
        $errors[] = 'Unable to locate certificate';
    }
    if (empty($errors)) {
        if (DeloProcessor::isCheckPaymentRequest()) {
            // Первая фаза проведения платежа
            DeloProcessor::paymentAvailabilityPositiveResponse($arOrder, $paymentSettings);
        } else {
            // Вторая фаза проведения платежа - подтверждение платежа
            $signatureCheck = DeloProcessor::checkSignature($paymentSettings, $orderId);
            if ($signatureCheck) {
                $amount = isset($_GET['amount']) ? DeloProcessor::penniesToRub($_GET['amount']) : 0;
                $authCode = isset($_GET['p_authcode']) ? $_GET['p_authcode'] : '';
                // Обновляем статус заказа в БД в зависимости от результата проведения платежа
                if (DeloProcessor::setStatusCode($orderId, $_GET['result_code'], $amount, $authCode, $paymentSettings, $_GET['ext_result_code'])) {
                    $responseXml = DeloProcessor::setResponse(1, 'OK');
                    DeloProcessor::logRecord($orderId, $responseXml);
                    DeloProcessor::sendResponse($responseXml);
                } else {
                    $responseXml = DeloProcessor::setResponse(2, 'Not update order status');
                    DeloProcessor::logRecord($orderId, $responseXml);
                    DeloProcessor::sendResponse($responseXml);
                }
            } else {
                $responseXml = DeloProcessor::setResponse(2, 'Digital Signature Verification Failed');
                DeloProcessor::logRecord($orderId, $responseXml);
                DeloProcessor::sendResponse($responseXml);
            }
        }
    } else {
        $responseXml = DeloProcessor::setResponse(2, implode("\n", $errors));
        DeloProcessor::logRecord($orderId, $responseXml);
        DeloProcessor::sendResponse($responseXml);
    }
} catch (Exception $exception) {
    // Если что-то пошло не так в связи с не предусмотренной ситуацией
    $responseXml = DeloProcessor::setResponse(2, implode("\n", $exception->getMessage()));
    DeloProcessor::sendResponse($responseXml);
}